@@ -8,11 +8,7 @@
 #include "xcbdpmshelper_p.h"
 
 #include <QGuiApplication>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-#include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
+#include <QtGui/private/qtx11extras_p.h>
 
 KScreen::Dpms::Dpms(QObject *parent)
     : QObject(parent)
@@ -49,3 +45,5 @@ bool KScreen::Dpms::hasPendingChanges() const
 {
     return m_helper->hasPendingChanges();
 }
+
+#include "moc_dpms.cpp"
